@@ -66,8 +66,9 @@ class AuthServerConnector:
         logger.info(f"{type(self).__name__} inited")
 
     async def validate_access_token(self, token: str, origin: str) -> JWTPayload:
-        answer = await self._connector.get(
-            path="v1/auth/access_token/validate",
+        answer = await self._connector.post(
+            path="v1/access_token/validate",
+            payload=None,
             headers={
                 hdrs.ORIGIN: origin,
                 hdrs.AUTHORIZATION: f"Bearer {token}",
